@@ -6,7 +6,7 @@ class Route:
     def __init__(self):
         self.interaktionen = []
         self.states = defaultdict(list)
-        self.action = defaultdict(list)
+        self.actions = defaultdict(list)
 
     def from_excel_dict(self, excel_dict):
         for excel_dict_item in excel_dict.items():
