@@ -15,7 +15,7 @@ def uhrzeit_filter():
     (Message(121123, date=datetime.now, chat=Chat(id=1212, type ="private"), text ="12"))
 ])
 def test_uhrzeit_filter_on_messages(uhrzeit_filter, message_text):
-    assert uhrzeit_filter.filter(message_text) == True
+    assert uhrzeit_filter.filter(message_text) is True
 
 @pytest.mark.parametrize("message_text", [
     (Message(121123, date=datetime.now, chat=Chat(id=1212, type ="private"), text ="weiß nicht")),
@@ -23,4 +23,4 @@ def test_uhrzeit_filter_on_messages(uhrzeit_filter, message_text):
     (Message(121123, date=datetime.now, chat=Chat(id=1212, type ="private"), text ="leer"))
 ])
 def test_uhrzeit_filter_on_false_messages(uhrzeit_filter, message_text):
-    assert uhrzeit_filter.filter(message_text) == False
\ No newline at end of file
+    assert uhrzeit_filter.filter(message_text) is False
\ No newline at end of file
